pub struct Markdown<'a> { /* private fields */ }Expand description
Markdown renderer
Implementations
Sourceimpl<'a> Markdown<'a>
impl<'a> Markdown<'a>
Sourcepub fn new(data: &'a str, base: &'a str, highlight: bool) -> Markdown<'a>
pub fn new(data: &'a str, base: &'a str, highlight: bool) -> Markdown<'a>
Create a new markdown renderer.
data should contain the markdown to be rendered and base should specify a relative url
prefix (for relative links and images).
Note: base will only affect markdown links and images, not inline html ones.